;-----------------------------------------------------------------------------
; frank the fruit fly
;-----------------------------------------------------------------------------
# pmio.asm is the include file that defines hardware register names 
# the file is included in the tutorial zip file

	.include "pm_init.s"
	pm_header "fruit flyfun", IRQ_KEY_POWER | IRQ_MUSIC | IRQ_PRC_COPY, 0
	.include "pmrom_music.s"
	.include "pmio.asm"

	.ram	ticker		1
	.ram	ticker2		1
	.ram	ticker3		1
	.ram	wingsflap	1
	.ram	frankdir	1
	.ram 	buttonpress 1
	.ram	screennumber 1
	.ram    health 1
	.ram    health10  1
	.ram	sfx_select	1
	.ram	bgm_select	1
	.ram	prc_tick	1
	.ram	screenlock	1
	.ram    collisiontimer 1
	.ram	bites 1
	.ram 	enemytimer 1
	.ram    enemytimersecs 1
	.ram    collisionxplus 1
	.ram    collisionxminus 1
	.ram    collisionyminus 1
	.ram	collisionyplus 1
	.ram 	enemydir 1
	.ram    levelnumber 1
	.ram	nextsnowtimer 1
	.ram    snowtimer 1
	.ram	snowtimersecs 1
	.ram 	fc 1

	; Power button, shutdown PM
irq_key_power:
	cint CINT_SHUTDOWN

	; Act as VSync counter
irq_prc_copy:
	push hl
	mov hl, prc_tick
	inc [hl]
	pop hl
	rirq IRQ_PRC_COPY

	; .equ		NN				IO_BEGIN		; you can use [NN+...] instead of [nn+...] when required
;-----------------------------------------------------------------------------
; I/O address offsets
;-----------------------------------------------------------------------------
	.equ		BUTTONS			$52
	.equ		VIDEO_0			$80
	.equ		VIDEO_1			$81
	.equ		VIDEO_TILEDATA	$82		; word
	.equ		COUNTER2		$08
	.equ		CPU0			$00
	.equ		CPU2			$02

;-----------------------------------------------------------------------------
; I/O bits
;-----------------------------------------------------------------------------
	.equ		BUTTON_A		$01
	.equ		BUTTON_B		$02
	.equ		BUTTON_C		$04
	.equ		BUTTON_UP		$08
	.equ		BUTTON_DOWN		$10
	.equ		BUTTON_LEFT		$20
	.equ		BUTTON_RIGHT	$40
	.equ		BUTTON_POWER	$80
	.equ		CPU2_SPEED		$08
	.equ		COUNTER2_START	$01
	.equ		COUNTER2_RESET	$02
	.equ		VIDEO_0_INVERT	$01
	.equ		VIDEO_0_TILED	$02
	.equ		VIDEO_0_ENABLE0	$08
	.equ		VIDEO_0_TSIZE0	$10
	.equ		VIDEO_0_TSIZE1	$20
	.equ		VIDEO_1_ENABLE1	$01
	.equ		VIDEO_1_SLOW0	$02
	.equ		VIDEO_1_SLOW1	$04

;-----------------------------------------------------------------------------
; Interrupt numbers
;-----------------------------------------------------------------------------
	.equ	IntSuspend		0x21
	.equ	IntShutdown		0x24
	
;-----------------------------------------------------------------------------
; Title screen Setup
;-----------------------------------------------------------------------------
main:  
	xor a,a
	mov [ticker],a
	mov [ticker2],a
	mov [ticker3],a
	mov [buttonpress],a
	mov [frankdir],a
	mov [screenlock],a
	
	mov a,0
	mov [bgm_select],a
	
	; Interrupts
	enable_irqs IRQ_KEY_POWER | IRQ_PRC_COPY	

	; Init sound engine and play music (BA = Master time, HL = RAM Ptr)
	mov ba, MAP_BASE
	mov hl, $00FF
	call pmmusic_init

	; Enable interrupt
	enable_mirq
	
	call music

    movb	b, 95
    movw	HL, TILEMAP+95
	
bglinear:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
	;mov		x1, title1
	;movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

	mov		x1, player
    movw	[REG_BASE+REG_LCD_SPRITEMEM], x1
	
    movb	[nn+REG_EVENT2P],INT2P_KEYPAD
    movb	[nn+REG_EVENT2S],INT2S_KEY_POWER

    ; Activate all interrupts
    mov		flags, 0

    movb	[nn+REG_LCD_CNT0], LCD0_RENDER|LCD0_TILEBG|LCD0_MAP12x16|LCD0_SPRITES
    movb	[nn+REG_LCD_CNT1], LCD1_ENABLE|LCD1_REFRESH1

	mov nn,OAM
	mov [nn+0],44
	mov [nn+1],55
	mov [nn+2],0
	mov [nn+3],OAM_ENABLE

	mov nn,REG_BASE
	
	jmp title_screen
	
start_game_:
	mov a,0
	mov [buttonpress],a	
	
	jmp start_game
	
;-----------------------------------------------------------------------------
; Move Frank
;-----------------------------------------------------------------------------	
frank_right1:
		mov		a, [nextsnowtimer]
		add		a, 50
		mov		[nextsnowtimer], a

	call frank_right11
	jmp frank_y_movement
	
frank_left1:
		mov		a, [nextsnowtimer]
		add		a, 50
		mov		[nextsnowtimer], a

	call frank_left11
	jmp frank_y_movement
	
frank_up1:
		mov		a, [nextsnowtimer]
		add		a, 50
		mov		[nextsnowtimer], a
	call frank_up
	jmp level_1
	
frank_down1:
		mov		a, [nextsnowtimer]
		add		a, 50
		mov		[nextsnowtimer], a
	call frank_down11
	jmp level_1
	
;-----------------------------------------------------------------------------
; Title screen
;-----------------------------------------------------------------------------
title_screen:
		mov		a, [frankdir] 
		cmp		a, 5
		jz		title_screen_2

		call read_keys
		test a, KEY_A
		jnz start_game_

title_screen_2:
		mov		a, [fc]
		inc		a
		mov		[fc], a
		
		test	a, 1
		jz		_t2
		
    mov		x1, title1
    jmp		_t1
_t2:
    mov		x1, title2

_t1:
		mov		[REG_BASE+REG_LCD_TILEBGMEM], x1

		mov		a, [OAM+0] 
		cmp		a, 109
		jz		start_game_now

		mov		a, [ticker]
		add		a, 1
		mov		[ticker], a
	
		mov		a, [ticker] 
		cmp		a, 255
		jl		move_frank___
	
		jmp title_screen
	
;-----------------------------------------------------------------------------
; Move Frank around.
;-----------------------------------------------------------------------------	
move_frank___:
	call move_frank
	jmp title_screen
		
move_frank:
		mov		a, [ticker2]
		add		a, 1
		mov		[ticker2], a
	
		mov		a, [ticker2] 
		cmp		a, 77
		jl		move_frank2
		
		ret
		
move_frank2:
		mov a,0
		mov [ticker2],a	
		
		mov		a, [ticker3]
		add		a, 1
		mov		[ticker3], a

		;call flap_wings

		mov		a, [ticker3] 
		cmp		a, 252
		jz		move_frank3
		
		ret

move_frank_111:
		mov		a, [ticker]
		add		a, 1
		mov		[ticker], a
	
		mov		a, [ticker] 
		cmp		a, 255
		jl		move_frank___2224234123424124

		ret

move_frank___2224234123424124:
		mov		a, [ticker2]
		add		a, 1
		mov		[ticker2], a
	
		mov		a, [ticker2] 
		cmp		a, 77
		jl		move_frank22
		
		ret
		
move_frank22:
		mov a,0
		mov [ticker2],a	
	
		mov		a, [ticker3]
		add		a, 1
		mov		[ticker3], a

		mov		a, [ticker3] 
		cmp		a, 252
		jz		move_frank_in_game

		ret	
		
move_frank_in_game:
		call flap_wings

		mov a,0
		mov [ticker3],a	

		call read_keys
		test a, KEY_RIGHT
		jnz frank_right11
		
		call read_keys
		test a, KEY_LEFT
		jnz frank_left1

frank_y_movement:
		call read_keys
		test a, KEY_UP
		jnz frank_up1
		
		call read_keys
		test a, KEY_DOWN
		jnz frank_down1	
		
		ret
	
move_frank3:
		call flap_wings

		mov a,0
		mov [ticker3],a	
	
		mov		a, [frankdir] 
		cmp		a, 5
		jz		frank_right	
	
		mov		a, [OAM+0] 
		cmp		a, 31
		jz		frank_down	
	
		mov		a, [OAM+1] 
		cmp		a, 29
		jz		frank_left
	
		mov		a, [OAM+0] 
		cmp		a, 80
		jz		frank_up

frank_right:
		mov		a, [OAM+0]
		add		a, 1
		mov		[OAM+0], a
	
		mov		a, [frankdir] 
		cmp		a, 5
		jz		frank_down_start	
	
		ret
	
frank_right11:
		mov		a, [OAM+0] 
		cmp		a, 96
		jg		next_screen_
		
		mov		a, [OAM+0]
		add		a, 1
		mov		[OAM+0], a
	
		ret
	
next_screen_:
		mov		a, [screenlock] 
		cmp		a, 0
		jg		nomove	

		mov		a, [screennumber]
		add		a, 1
		mov		[screennumber], a	

		mov a,24
		mov [OAM+0],a	

		jmp next_screen
	
frank_up:
		mov		a, [OAM+1] 
		cmp		a, 17
		jz		nomove

		mov		a, [OAM+1]
		sub		a, 1
		mov		[OAM+1], a
	
nomove:
		ret
		
frank_left:
		mov		a, [OAM+0] 
		cmp		a, 5
		jz		frank_right	

frank_left11:
		mov		a, [OAM+0] 
		cmp		a, 24
		jz		nomove

		mov		a, [OAM+0]
		sub		a, 1
		mov		[OAM+0], a
	
		ret
		
frank_down_start:
		mov		a, [wingsflap] 
		cmp		a, 2
		jl		frank_down
		
		ret
		
frank_down:
		mov		a, [OAM+1]
		add		a, 1
		mov		[OAM+1], a
	
		mov		a, [OAM+1] 
		cmp		a, 55
		jz		frank_right	

		ret
		
frank_down11:
		mov		a, [OAM+1] 
		cmp		a, 72
		jz		nomove

		mov		a, [OAM+1]
		add		a, 1
		mov		[OAM+1], a
		ret

start_game_now:
		mov a,1
		mov [levelnumber],a	
	
		mov a,24
		mov [OAM+0],a				
	
		mov a,24
		mov [OAM+1],a	
		
		mov a,6
		mov [frankdir],a	
		
		mov a,0
		mov [ticker],a
		
	mov a,106
	mov [health],a

	mov a,106
	mov [health10],a

	call show_health
	
level_1_splash_screen:
		mov		x1, level1intro		
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

	mov		x1, player
    movw	[REG_BASE+REG_LCD_SPRITEMEM], x1

	mov nn,OAM
	mov [nn+0],44
	mov [nn+1],55
	mov [nn+2],0
	mov [nn+3],OAM_DISABLE

	mov nn,REG_BASE

	mov hl, bgm_select
	mov a, 1
	cmp [hl], a
	;jz nomove
	inc [hl]
	mov a, 8
	
	call show_health
	
	call music

		mov a,0
		mov [enemytimer],a
		
		mov a,0
		mov [enemytimersecs],a

level_1_intro_music_is_playing:
		call do_i_suspend

		mov		a, [enemytimer]
		add		a, 1
		mov		[enemytimer], a
		
		mov		a, [enemytimer] 
		cmp		a, 255
		jz		level_1_splash_seconds
	
		jmp level_1_intro_music_is_playing
	
level_1_splash_seconds:
		mov		a, [enemytimersecs]
		add		a, 1
		mov		[enemytimersecs], a
		
		mov		a, [enemytimersecs] 
		cmp		a, 185
		jz		level_1_splash_over

		jmp level_1_intro_music_is_playing
	
level_1_splash_over:  
		mov a,1
		mov [screennumber],a
	
		mov a,0
		mov [enemytimer],a
		
		mov a,0
		mov [enemytimersecs],a	
	
		mov hl, bgm_select
	mov a, 2
	cmp [hl], a
	;jz nomove
	inc [hl]
	mov a, 8	

	call show_health

	call music

	mov nn,OAM
	mov [nn+0],33
	mov [nn+1],55
	mov [nn+2],0
	mov [nn+3],OAM_ENABLE
	
	
		jmp next_screen

;-----------------------------------------------------------------------------
; Level 1
;-----------------------------------------------------------------------------
level_1:
		call move_frank_111
		
		mov		a, [nextsnowtimer]
		inc 	a
		mov		[nextsnowtimer], a

		mov		a, [nextsnowtimer] 	
		cmp		a, 100
		jg		reset_snow_1
		
		jmp level_1_2
		
reset_snow_1:
		mov a,25
		mov [nextsnowtimer],a	

level_1_2:
		mov		a, [levelnumber] 	
		cmp		a, 2
		jz		level_2	

		mov		a, [screennumber] 	
		cmp		a, 1
		jz		screen_2_stuff	
		
		cmp		a, 2
		jz		screen_2_stuff		
		
		cmp		a, 3
		jz		screen_3_stuff	
		
		cmp		a, 4
		jz		screen_4_stuff		

		cmp		a, 5
		jz		screen_5_stuff	
		
		cmp		a, 6
		jz		screen_6_stuff	
		
		cmp		a, 7
		jz		screen_7_stuff	
		
		cmp		a, 8
		jz		screen_8_stuff			
		
		cmp		a, 9
		jz		screen_9_stuff			
	
		cmp		a, 10
		jz		screen_10_stuff			
	
		jmp 	level_1
;-----------------------------------------------------------------------------
; Flap Wings
;-----------------------------------------------------------------------------		
flap_wings:
		call do_i_suspend

		mov		a, [wingsflap]
		add		a, 1
		mov		[wingsflap], a

		mov		a, [wingsflap] 
		cmp		a, 2
		jg		wings_down

		mov a,1
		mov [OAM+2],a
		
		ret
		
wings_down:
		mov		a, [wingsflap] 
		cmp		a, 4
		jz		reset_wings

		mov a,0
		mov [OAM+2],a
		
		ret

reset_wings:
		mov a,0
		mov [wingsflap],a
		
		ret	
		
level_2_splash_screen_ffff:
			jmp level_2_splash_screen
		
;-----------------------------------------------------------------------------
; Game Starting code/animation
;-----------------------------------------------------------------------------			
start_game:
		mov a,5
		mov [frankdir],a

		mov a,1		; change to 1 when finished
		mov [screennumber],a

		jmp title_screen

next_screen:
		mov		a, [screennumber] 
		cmp		a, 11
		jz		level_2_splash_screen_ffff	
		
		cmp		a, 10
		jz		screen10setup			
		
		cmp		a, 9
		jz		screen9setup		
		
		cmp		a, 8
		jz		screen8setup		
		
		cmp		a, 7
		jz		screen7setup		
		
		cmp		a, 6
		jz		screen6setup

		cmp		a, 5
		jz		screen5setup
		
		cmp		a, 4
		jz		screen4setup		
		
		cmp		a, 3
		jz		screen3setup	
		
		cmp		a, 2
		jz		screen2setup			
		
		cmp		a, 1
		jz		screen1setup		

		jmp level_1
		
		
;-----------------------------------------------------------------------------	
; screen 1 setup
;-----------------------------------------------------------------------------	
screen1setup:   
	movb	b, 95
    movw	HL, TILEMAP+95
	
bglinear3dddd:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear3dddd
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
		mov		x1, screen1
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

		mov x1, TILEMAP+23
		mov a, 2	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 2	
		mov [x1], a
		
		call show_health

		jmp level_1
		
;-----------------------------------------------------------------------------	
; screen 2 setup
;-----------------------------------------------------------------------------			
screen2setup:
		mov x1, TILEMAP+23
		mov a, 97	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 97	
		mov [x1], a
		
		mov x1, TILEMAP+47
		mov a, 97	
		mov [x1], a

		mov x1, TILEMAP+59
		mov a, 97	
		mov [x1], a

		mov a,2
		mov [screenlock],a
		
	;call pmmusic_stopbgm

		jmp level_1
;-----------------------------------------------------------------------------	
; screen 2 stuff
;-----------------------------------------------------------------------------				
screen_2_stuff:
		mov		a, [OAM+0] 
		cmp		a, 88
		jl		level_11

		call move_frank_111

		call read_keys
		test a, KEY_A
		jnz test_where_frank_y1
			
		mov		a, [buttonpress] 
		cmp		a, 1
		jz		bp1
		
		mov a,0
		mov [buttonpress],a	

level_11:
		jmp level_1

bp1:
		mov a,2
		mov [buttonpress],a		
		
		jmp bp2

test_where_frank_y1:
		mov		a, [buttonpress] 
		cmp		a, 2
		jz		bp2

		mov a,1
		mov [buttonpress],a

		jmp level_1

bp2:
		mov		a, [screenlock]
		cmp		a, 2
		jz		screen_lock_2
		
		mov		a, [screenlock]
		cmp		a, 3
		jz		screen_lock_3
		
		mov		a, [screenlock]
		cmp		a, 4
		jz		screen_lock_4
		
		; button 4 (48)

		mov		a, [OAM+1] 
		cmp		a, 47
		jl		no_lock

		mov		a, [OAM+1] 
		cmp		a, 52
		jg		no_lock
		
	mov b, 0
	mov a, 1
	shl a
	shl a
	mov hl, sfx_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playsfx		
		
		mov a,0
		mov [screenlock],a		
		
		jmp level_1
		
screen_lock_2:
		; button 1 (32)

		mov		a, [OAM+1] 
		cmp		a, 31
		jl		no_lock

		mov		a, [OAM+1] 
		cmp		a, 35
		jg		no_lock
		
		jmp unlock_step
		
screen_lock_3:
		; button 2 (40)

		mov		a, [OAM+1] 
		cmp		a, 39
		jl		no_lock

		mov		a, [OAM+1] 
		cmp		a, 43
		jg		no_lock
		
		jmp unlock_step	

screen_lock_4:
		; button 3 (24)

		mov		a, [OAM+1] 
		cmp		a, 23
		jl		no_lock

		mov		a, [OAM+1] 
		cmp		a, 27
		jg		no_lock
		
		jmp unlock_step	
		
no_lock:
	mov b, 0
	mov a, 0
	shl a
	shl a
	mov hl, sfx_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playsfx

		mov a,2
		mov [screenlock],a

		mov		a, [health]
		sub		a, 2
		mov		[health], a		
	
		mov		a, [health]
		cmp		a, 97
		jl		health_ten

		call show_health

		jmp level_1
		
health_ten:
		mov		a, [health]
		add		a, 10
		mov		[health], a	

		mov		a, [health10]
		sub		a, 1
		mov		[health10], a		
		
		call show_health		
		
		jmp level_1
		
unlock_step:
	mov b, 0
	mov a, 1
	shl a
	shl a
	mov hl, sfx_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playsfx

		mov		a, [screenlock]
		add		a, 1
		mov		[screenlock], a	
		
		jmp level_1

;-----------------------------------------------------------------------------	
; screen 3 setup
;-----------------------------------------------------------------------------	
screen3setup:   
	movb	b, 95
    movw	HL, TILEMAP+95
	
bglinear3:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear3
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
		mov		x1, screen3
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

		mov x1, TILEMAP+23
		mov a, 2	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 2	
		mov [x1], a
		
		call show_health

		jmp level_1

;-----------------------------------------------------------------------------	
; screen 3 stuff
;-----------------------------------------------------------------------------	
screen_3_stuff:	
		call move_frank_111

		mov		a, [OAM+0] 
		cmp		a, 82
		jg		level_1_	

check_web_1a:	
		mov		a, [OAM+0] 
		cmp		a, 48
		jl		check_web_1b	

screen_3_stuff_2:
		mov		a, [OAM+0] 
		cmp		a, 56
		jg		check_web_2a		
		
level_1_:
		mov a,0
		mov [buttonpress],a	

		jmp level_1	

screen_3_stuff_2a:	
		mov		a, [OAM+1] 
		cmp		a, 22
		jg		check_web_1b

		jmp level_1
		
check_web_1b:
		mov		a, [OAM+1] 
		cmp		a, 28
		jg		check_web_1c	

		jmp level_1

check_web_1c:	
		mov		a, [OAM+1] 
		cmp		a, 52
		jl		lose_health_no_touch

		jmp level_1
		
check_web_2a:
		mov		a, [OAM+1] 
		cmp		a, 40
		jl		lose_health_no_touch	
		
check_web_2b:
		mov		a, [OAM+1] 
		cmp		a, 48
		jg		lose_health_no_touch

		jmp level_1
		
lose_health_no_touch:
		mov		a, [collisiontimer]
		add		a, 1
		mov 	[collisiontimer],a	

		mov		a, [collisiontimer] 
		cmp		a, 254
		jz		lose_health2
		
		jmp level_1

lose_health2:
		mov a,0
		mov [collisiontimer],a	

	mov b, 0
	mov a, 0
	shl a
	shl a
	mov hl, sfx_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playsfx
	
	jmp lose_health3
	
lose_health:
	mov b, 0
	mov a, 0
	shl a
	shl a
	mov hl, sfx_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playsfx

		mov		a, [buttonpress]
		add		a, 1
		mov 	[buttonpress],a
			
		mov		a, [buttonpress] 
		cmp		a, 255
		jz		lose_health3
			
		jmp level_1
		
lose_health3:
		mov a,0
		mov [buttonpress],a
	
		mov		a, [health]
		sub		a, 1
		mov		[health], a		
	
		mov		a, [health]
		cmp		a, 97
		jl		health_ten_

		call show_health

		jmp level_1

health_ten_:
			jmp health_ten

;-----------------------------------------------------------------------------	
; screen 4 setup
;-----------------------------------------------------------------------------			
screen4setup: 
	movb	b, 95
    movw	HL, TILEMAP+95
	
bglinear4:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear4
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
		mov		x1, screen4
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

		mov x1, TILEMAP+23
		mov a, 2	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 2	
		mov [x1], a
		
		call show_health

		mov a,0
		mov [buttonpress],a	
		
	;call pmmusic_stopbgm

		jmp level_1

;-----------------------------------------------------------------------------	
; screen 4 stuff
;-----------------------------------------------------------------------------	
screen_4_stuff:
		mov		a, [buttonpress] 
		cmp		a, 1
		jz		bite_that_fruit

		call read_keys
		test a, KEY_A
		jnz bite_that_fruit
		
		call move_frank_111	
		
		jmp level_1
		
bite_that_fruit:
		call read_keys
		test a, KEY_A
		jnz stop_biting2

		mov		a, [OAM+0] 
		cmp		a, 45
		jl		stop_biting	

		mov		a, [OAM+0] 
		cmp		a, 88
		jg		stop_biting	

		mov		a, [OAM+1] 
		cmp		a, 50
		jl		stop_biting	
		
		mov		a, [OAM+1] 
		cmp		a, 70
		jg		stop_biting		

		mov		a, [bites]
		add		a, 1
		mov 	[bites],a
			
		mov		a, [bites] 
		cmp		a, 5
		jl		increase_health
		
		jmp stop_biting
		
increase_health:
		mov		a, [health]
		add		a, 2
		mov 	[health],a	
		
		call add_score
	
stop_biting:
		mov a,0
		mov [buttonpress],a

		jmp level_1
		
stop_biting2:		
		mov a,1
		mov [buttonpress],a
		jmp level_1
;-----------------------------------------------------------------------------	
; screen 5 setup
;-----------------------------------------------------------------------------			
screen5setup: 
	movb	b, 95
    movw	HL, TILEMAP+95
	
bglinear5:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear5
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
		mov		x1, screen5
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

		mov x1, TILEMAP+23
		mov a, 2	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 2	
		mov [x1], a
		
		call show_health

		mov a,0
		mov [buttonpress],a	
		
		jmp level_1
		
;-----------------------------------------------------------------------------	
; screen 5 stuff
;-----------------------------------------------------------------------------
dont_go_back_in_fucker_:
		jmp dont_go_back_in_fucker
			
screen_5_stuff:
		call move_frank_111

		mov		a, [OAM+0] 
		cmp		a, 58
		jg		dont_go_back_in_fucker_

		mov		a, [OAM+0] 
		cmp		a, 32
		jl		skip_cat

		mov		a, [OAM+0] 
		cmp		a, 48
		jg		up_cats_head

		mov		a, [OAM+1] 
		cmp		a, 30
		jz		in_cat_mouth
		
		mov		a, [OAM+1] 
		cmp		a, 32
		jz		in_cat_mouth		
	
		mov		a, [OAM+1] 
		cmp		a, 31
		jz		in_cat_mouth	
	
		mov a,32
		mov [OAM+0],a			
		
skip_cat:		
		jmp level_1
		
in_cat_mouth:
		mov		a, [OAM+0] 
		cmp		a, 48
		jg		up_cats_head

		mov a,31
		mov [OAM+1],a		
		
		jmp level_1

hit_throat_back:
		mov		a, [OAM+1] 
		cmp		a, 31
		jl		skip_forcex50

		mov		a, [health]
		sub		a, 3
		mov 	[health],a	

		mov a,254
		mov [buttonpress],a	
		
		mov a,32
		mov [OAM+0],a		

		jmp lose_health			

up_cats_head:
		mov		a, [OAM+0] 
		cmp		a, 59
		jg		skip_cat

		mov a,15
		mov [OAM+2],a

		mov		a, [OAM+0] 
		cmp		a, 52
		jz		hit_throat_back

		mov		a, [OAM+1] 
		cmp		a, 18
		jl		out_of_cats_head
		
		mov		a, [OAM+1] 
		cmp		a, 31
		jz		skip_forcex50_2

forcex50:
		mov a,15
		mov [OAM+2],a

		mov a,51
		mov [OAM+0],a			

skip_forcex50:
		jmp level_1

skip_forcex50_2:
		mov		a, [OAM+0] 
		cmp		a, 52
		jz		hit_throat_back
		
		mov a,15
		mov [OAM+2],a		
		
		jmp level_1

out_of_cats_head:
		mov a,60
		mov [OAM+0],a
		
		jmp level_1

dont_go_back_in_fucker:
		mov		a, [OAM+0] 
		cmp		a, 59
		jz		force_60
		
		jmp level_1
		
force_60:
		mov a,60
		mov [OAM+0],a

		jmp level_1
		
;-----------------------------------------------------------------------------	
; screen 6 setup
;-----------------------------------------------------------------------------			
screen6setup: 
	movb	b, 95
    movw	HL, TILEMAP+95
	
bglinear6:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear6
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
		mov		x1, screen6
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

		mov x1, TILEMAP+23
		mov a, 2	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 2	
		mov [x1], a
		
		call show_health

		mov a,0
		mov [buttonpress],a	
		
	mov nn,OAM
	mov [nn+4],100
	mov [nn+5],25
	mov [nn+6],2
	mov [nn+7],OAM_ENABLE

	mov nn,REG_BASE		
		
		jmp level_1
		
;-----------------------------------------------------------------------------	
; screen 6 stuff
;-----------------------------------------------------------------------------
screen_6_stuff:
		call move_frank_111

		mov		a, [wingsflap] 
		cmp		a, 2
		jg		wings_down_bee

		mov a,2
		mov [OAM+6],a

		jmp do_i_move_bee
			
wings_down_bee:
		mov a,3
		mov [OAM+6],a	

do_i_move_bee:
		mov		a, [enemytimer]
		inc 	a
		mov		[enemytimer], a

		mov		a, [enemytimer]
		cmp		a, 255
		jz		new_seconds

		jmp no_collision
		
new_seconds:
		mov a,0
		mov [enemytimer],a	
		
		mov		a, [enemytimersecs]
		inc 	a
		mov		[enemytimersecs], a		
		
		cmp		a, 1
		jg		bee_movement_x
		
		jmp no_collision
		
bee_movement_x:
		mov a,0
		mov [enemytimersecs],a

		mov		a, [OAM+4] 
		cmp		a, [OAM+0]
		jg		bee_left

bee_right:
		mov		a, [OAM+4]
		inc 	a
		mov		[OAM+4], a
		
		jmp bee_movement_y
		
bee_left:
		mov		a, [OAM+4]
		dec 	a
		mov		[OAM+4], a
		
bee_movement_y:
		mov		a, [collisionyminus] 
		cmp		a, [OAM+1]
		jg		bee_up

bee_down:
		mov		a, [OAM+5]
		inc 	a
		mov		[OAM+5], a
		
		jmp bee_collision
		
bee_up:
		mov		a, [OAM+5]
		dec 	a
		mov		[OAM+5], a	

bee_collision:
		mov		a, [OAM+5]
		add 	a, 8
		mov		[collisionyminus], a	

		mov		a, [OAM+5]
		add 	a, 16
		mov		[collisionyplus], a		
		
		mov		a, [OAM+4]
		sub 	a, 4
		mov		[collisionxminus], a	

		mov		a, [OAM+4]
		add 	a, 4
		mov		[collisionxplus], a	

		mov		a, [collisionxplus] 
		cmp		a, [OAM+0]
		jl		no_collision

		mov		a, [collisionxminus] 
		cmp		a, [OAM+0]
		jg		no_collision

		mov		a, [collisionyplus] 
		cmp		a, [OAM+1]
		jl		no_collision

		mov		a, [collisionyminus] 
		cmp		a, [OAM+1]
		jg		no_collision

frank_got_stung:
		mov		a, [health]
		sub		a, 4
		mov 	[health],a	

		mov a,254
		mov [buttonpress],a	
	
		mov		a, [OAM+0]
		cmp		a, 50
		jg		bee_reappear_left
	
		mov a,100
		mov [OAM+4],a		

		jmp lose_health				

bee_reappear_left:
		mov a,36
		mov [OAM+4],a		

		jmp lose_health	

no_collision:	

		jmp level_1
;-----------------------------------------------------------------------------	
; screen 7 setup
;-----------------------------------------------------------------------------			
screen7setup: 
	movb	b, 95
    movw	HL, TILEMAP+95
	
bglinear7:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear7
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
		mov		x1, screen7
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

		mov x1, TILEMAP+23
		mov a, 2	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 2	
		mov [x1], a
		
		call show_health

		mov a,0
		mov [buttonpress],a	
		mov [bites],a
		
	mov nn,OAM
	mov [nn+7],OAM_DISABLE

	mov nn,REG_BASE		
		
		jmp level_1		

;-----------------------------------------------------------------------------	
; screen 7 stuff
;-----------------------------------------------------------------------------	
screen_7_stuff:
		mov		a, [buttonpress] 
		cmp		a, 1
		jz		bite_that_cherry

		call read_keys
		test a, KEY_A
		jnz bite_that_cherry
		
		call move_frank_111	
		
		jmp level_1
		
bite_that_cherry:
		call read_keys
		test a, KEY_A
		jnz stop_biting2_7

		mov		a, [OAM+0] 
		cmp		a, 45
		jl		stop_biting_7	

		mov		a, [OAM+0] 
		cmp		a, 66
		jg		stop_biting_7	

		mov		a, [OAM+1] 
		cmp		a, 56
		jl		stop_biting_7
		
		mov		a, [OAM+1] 
		cmp		a, 70
		jg		stop_biting_7		

		mov		a, [bites]
		add		a, 1
		mov 	[bites],a
			
		mov		a, [bites] 
		cmp		a, 5
		jl		increase_health_7
		
		jmp stop_biting_7
		
increase_health_7:
		mov		a, [health]
		add		a, 2
		mov 	[health],a	
		
		call add_score
	
stop_biting_7:
		mov a,0
		mov [buttonpress],a

		jmp level_1
		
stop_biting2_7:		
		mov a,1
		mov [buttonpress],a
		jmp level_1

;-----------------------------------------------------------------------------
; screen 8 setup
;-----------------------------------------------------------------------------
screen8setup: 
	movb	b, 95
    movw	HL, TILEMAP+95
bglinear8:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear8
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
		mov		x1, screen8
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

		mov x1, TILEMAP+23
		mov a, 2	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 2	
		mov [x1], a
		
		call show_health

		mov a,0
		mov [buttonpress],a	
		mov [bites],a
		mov [enemytimer],a
		mov [enemytimersecs],a
		
		mov a,2
		mov [enemydir],a			

	; frog body
	mov nn,OAM
	mov [nn+4],56
	mov [nn+5],45
	mov [nn+6],4
	mov [nn+7],OAM_ENABLE

	; frog tongue
	mov nn,OAM
	mov [nn+8],46
	mov [nn+9],34
	mov [nn+10],6
	mov [nn+11],OAM_ENABLE

	mov nn,REG_BASE			
	
	jmp level_1
	
;-----------------------------------------------------------------------------	
; screen 8 stuff
;-----------------------------------------------------------------------------	
screen_8_stuff:

		call move_frank_111	

		mov		a, [enemytimer]
		add 	a, 1
		mov		[enemytimer], a	

		mov		a, [enemydir]
		cmp 	a, 3
		jz 		frog_sit

		mov		a, [enemytimer]
		cmp 	a, 96
		jz 		frog_facing
		
		jmp end_frog
		
	
frog_fall___:
		jmp frog_fall
	
frog_jump:
		mov a,0
		mov [enemytimersecs],a

		mov a,2
		mov [enemydir],a

		mov		a, [OAM+5]
		sub 	a, 2
		mov		[OAM+5], a	

		mov		a, [OAM+9]
		sub 	a, 2
		mov		[OAM+9], a		
		
		mov		a, [OAM+5]
		cmp 	a, 25
		jl		frog_fall___

		jmp end_frog
	
	
frog_sit:
		mov		a, [enemytimer]
		cmp 	a, 94
		jz		add_seconds
		
		jmp frog_is_sitting

add_seconds:
		mov		a, [enemytimersecs]
		add 	a, 1
		mov		[enemytimersecs], a	

		mov		a, [enemytimersecs]
		cmp 	a, 10
		jg 		frog_jump


frog_is_sitting:
		mov a,3
		mov [enemydir],a

		mov		a, [OAM+0]
		cmp 	a, 56
		jg 		frog_sit_right
		
		mov a,8
		mov [OAM+6],a
		mov a,6
		mov [OAM+10],a	
		mov a,46
		mov [OAM+8],a

		jmp end_frog
		

frog_sit_right:
		mov a,9
		mov [OAM+6],a
		mov a,7
		mov [OAM+10],a	
		mov a,66
		mov [OAM+8],a

		jmp end_frog

;===	

frog_facing:
		mov a,0
		mov [enemytimer],a

		mov		a, [enemydir]
		cmp 	a, 3
		jz 		frog_sit_	

		mov		a, [OAM+0]
		cmp 	a, 56
		jg 		frog_face_right
			
		mov a,4
		mov [OAM+6],a
		mov a,6
		mov [OAM+10],a	
		mov a,46
		mov [OAM+8],a

		jmp move_frog
		
frog_face_right:
		mov a,5
		mov [OAM+6],a
		mov a,7
		mov [OAM+10],a	
		mov a,66
		mov [OAM+8],a

move_frog:
		mov		a, [enemydir]
		cmp 	a, 3
		jz 		frog_sit	

		mov		a, [enemydir]
		cmp 	a, 2
		jz 		frog_jump
		
frog_fall:
		mov a,1
		mov [enemydir],a

		mov		a, [OAM+5]
		add 	a, 2
		mov		[OAM+5], a	

		mov		a, [OAM+9]
		add 	a, 2
		mov		[OAM+9], a		
		
		mov		a, [OAM+5]
		cmp 	a, 65
		jg 		frog_sit____

		jmp end_frog
		
frog_sit____:
		mov a,0
		mov [enemytimer],a

frog_sit_:
		jmp frog_sit

end_frog:
		mov		a, [buttonpress]
		cmp 	a, 254
		jz 		no_collision_frog2
		
frog_collision:	
		call move_frank_111	
		
		mov		a, [OAM+0] 
		cmp		a, 48
		jl		tongue_collision_x

		mov		a, [OAM+0] 
		cmp		a, 64
		jg		tongue_collision_x		
		
		mov		a, [OAM+5]
		add 	a, 0
		mov		[collisionyminus], a			
		
		mov		a, [OAM+5]
		add 	a, 16
		mov		[collisionyplus], a			
		
		mov		a, [collisionyplus] 
		cmp		a, [OAM+1]
		jl		tongue_collision_x

		mov		a, [collisionyminus] 
		cmp		a, [OAM+1]
		jg		tongue_collision_x
		
		jmp collision_happened

tongue_collision_x:
		call move_frank_111	
		
		; you have to check x and y at the same time or else it won't work!
		
		mov		a, [OAM+8]
		sub 	a, 8
		mov		[collisionxminus], a		

		mov		a, [OAM+8]
		add 	a, 8
		mov		[collisionxplus], a			
		
		mov		a, [collisionxplus] 
		cmp		a, [OAM+0]
		jl		no_collision_frog2 

		mov		a, [collisionxminus] 
		cmp		a, [OAM+0]
		jg		no_collision_frog2 


		
		mov		a, [OAM+9]
		add 	a, 8
		mov		[collisionyplus], a			
		
		mov		a, [collisionyplus] 
		cmp		a, [OAM+1]
		jl		no_collision_frog2
		
		mov		a, [OAM+9] 
		cmp		a, [OAM+1]
		jg		no_collision_frog2
	
		jmp collision_happened	
		
no_collision_frog2:		
		mov a,0
		mov [buttonpress],a

		jmp level_1
		
collision_happened:	
		mov		a, [buttonpress]
		add 	a, 1
		mov		[buttonpress], a	

		mov		a, [buttonpress] 
		cmp		a, 1
		jz		take_away_health
		
		jmp level_1

take_away_health:
	mov b, 0
	mov a, 0
	shl a
	shl a
	mov hl, sfx_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playsfx
	
		mov		a, [health]
		sub		a, 2
		mov		[health], a		
	
		mov		a, [health]
		cmp		a, 97
		jl		health_tenff

		call show_health

		jmp level_1

health_tenff:
		mov		a, [health]
		add		a, 10
		mov		[health], a	

		mov		a, [health10]
		sub		a, 1
		mov		[health10], a		
		
		call show_health	

		jmp level_1
;-----------------------------------------------------------------------------
; screen 9 setup
;-----------------------------------------------------------------------------
screen9setup: 
	movb	b, 95
    movw	HL, TILEMAP+95
bglinear9:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear9
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
		mov		x1, screen9
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

		mov x1, TILEMAP+23
		mov a, 2	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 2	
		mov [x1], a
		
		call show_health

		mov a,0
		mov [buttonpress],a	
		mov [bites],a
		
		mov a,2
		mov [enemydir],a	

	mov nn,OAM
	mov [nn+8],OAM_DISABLE
	
	mov nn,OAM
	mov [nn+4],OAM_DISABLE

	mov nn,REG_BASE		
		
		jmp level_1		

;-----------------------------------------------------------------------------
; screen 9 stuff
;-----------------------------------------------------------------------------

screen_9_stuff:
		mov		a, [buttonpress] 
		cmp		a, 1
		jz		bite_that_strawberry

		call read_keys
		test a, KEY_A
		jnz bite_that_strawberry
		
		call move_frank_111	
		
		jmp level_1
		
bite_that_strawberry:
		call move_frank_111	

		call read_keys
		test a, KEY_A
		jnz stop_biting2_9

		mov		a, [OAM+0] 
		cmp		a, 35
		jl		stop_biting_9	

		mov		a, [OAM+0] 
		cmp		a, 72
		jg		stop_biting_9	

		mov		a, [OAM+1] 
		cmp		a, 36
		jl		stop_biting_9
		
		mov		a, [OAM+1] 
		cmp		a, 79
		jg		stop_biting_9	

		mov		a, [bites]
		add		a, 1
		mov 	[bites],a
			
		mov		a, [bites] 
		cmp		a, 5
		jl		increase_health_9
		
		jmp stop_biting_9
		
increase_health_9:

		
		jmp take_away_health9
		
		call add_score
	
stop_biting_9:
		mov a,0
		mov [buttonpress],a

		jmp level_1
		
stop_biting2_9:		
		mov a,1
		mov [buttonpress],a
		jmp level_1
		
take_away_health9:

		mov a,0
		mov [buttonpress],a

	mov b, 0
	mov a, 0
	shl a
	shl a
	mov hl, sfx_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playsfx
	
		mov		a, [health]
		sub		a, 4
		mov		[health], a		
	
		mov		a, [health]
		cmp		a, 97
		jl		health_tenff9

		call show_health

		jmp level_1

health_tenff9:
		mov		a, [health]
		add		a, 10
		mov		[health], a	

		mov		a, [health10]
		sub		a, 1
		mov		[health10], a		
		
		call show_health	

		jmp level_1
	
;-----------------------------------------------------------------------------
; screen 10 setup
;-----------------------------------------------------------------------------
screen10setup: 
	movb	b, 95
    movw	HL, TILEMAP+95
bglinear10:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear10
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
		mov		x1, screen10
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

		mov x1, TILEMAP+23
		mov a, 2	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 2	
		mov [x1], a
		
		call show_health

		mov a,0
		mov [buttonpress],a	
		mov [bites],a
		
		mov a,0					; put this back to 2
		mov [screenlock],a	

		mov nn,REG_BASE		
		
		jmp level_1	
	
;----------------
; screen 10 stuff
;----------------	
screen_10_stuff:
	
		mov		a, [OAM+1] 
		cmp		a, 25
		jl		free_movement	
	
		; tree 1
	
		mov		a, [OAM+0] 
		cmp		a, 35
		jz		avoid_movement_minus
	
		mov		a, [OAM+0] 
		cmp		a, 42
		jz		avoid_movement_plus	
	
		mov		a, [OAM+0] 
		cmp		a, 35
		jg		avoid_movement_y1
		
		jmp tree2
		
avoid_movement_y1:
		mov		a, [OAM+0] 
		cmp		a, 42
		jl		avoid_movement_y
		

	
tree2:
		; tree 2

		mov		a, [OAM+0] 
		cmp		a, 71
		jz		avoid_movement_minus
	
		mov		a, [OAM+0] 
		cmp		a, 78
		jz		avoid_movement_plus	

	
		mov		a, [OAM+0] 
		cmp		a, 71
		jg		tree2y
		
		
				call move_frank_111		
		jmp free_movement
		
tree2y:
	
		mov		a, [OAM+0] 
		cmp		a, 77
		jl		avoid_movement_y
		

		
		
			call move_frank_111		

free_movement:
		mov		a, [OAM+0] 
		cmp		a, 42
		jg		do_i_unlock_screen10

		mov		a, [OAM+0] 
		cmp		a, 71
		jl		do_i_unlock_screen10	
	
		jmp avoid_movement
		
avoid_movement_plus:
		mov		a, [OAM+0]
		add		a, 1
		mov		[OAM+0], a				
		
		jmp avoid_movement
	
avoid_movement_minus:
		mov		a, [OAM+0]
		sub		a, 1
		mov		[OAM+0], a				
		
		jmp avoid_movement
		
avoid_movement_y:
		mov		a, [OAM+1]
		sub		a, 1
		mov		[OAM+1], a				
		
		jmp avoid_movement
	
avoid_movement_ggg:

		mov a,43
		mov [OAM+0],a			
		
		jmp avoid_movement
		
do_i_unlock_screen10:
		mov		a, [OAM+1] 
		cmp		a, 70
		jg		unlock_screen_10
	
		jmp avoid_movement

unlock_screen_10:
		mov a,0
		mov [screenlock],a	
	
		mov a,69
		mov [OAM+1],a		
	
	mov b, 0
	mov a, 1
	shl a
	shl a
	mov hl, sfx_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playsfx



avoid_movement:
		call move_frank_111	
	
		jmp level_1
	
	
;-----------
; level 2 intro
;-----------
level_2_splash_screen:   
	movb	b, 95
    movw	HL, TILEMAP+95
	
bglinear3ddddf:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear3ddddf
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE	

	call show_health

	mov		x1, level2intro		
	movw	[REG_BASE+REG_LCD_TILEBGMEM], x1

	mov		x1, player2
    movw	[REG_BASE+REG_LCD_SPRITEMEM], x1

	mov nn,OAM
	mov [nn+0],44
	mov [nn+1],55
	mov [nn+2],0
	mov [nn+3],OAM_DISABLE

	mov nn,REG_BASE

	mov a,1
	mov [bgm_select],a
	
	call music

		mov a,2
		mov [levelnumber],a

		mov a,0
		mov [enemytimer],a
		
		mov a,0
		mov [enemytimersecs],a

level_2_intro_music_is_playing:
		call do_i_suspend

		mov		a, [enemytimer]
		add		a, 1
		mov		[enemytimer], a
		
		mov		a, [enemytimer] 
		cmp		a, 255
		jz		level_2_splash_seconds
	
		jmp level_2_intro_music_is_playing
	
level_2_splash_seconds:
		mov		a, [enemytimersecs]
		add		a, 1
		mov		[enemytimersecs], a
		
		mov		a, [enemytimersecs] 
		cmp		a, 185
		jz		level_2_splash_over

		jmp level_2_intro_music_is_playing
	
level_2_splash_over:  
		mov a,11
		mov [screennumber],a
	
		mov a,0
		mov [enemytimer],a
		
		mov a,0
		mov [enemytimersecs],a	
	
	mov a,2
	mov [bgm_select],a
	;jz nomove
	inc [hl]
	mov a, 8	

	call show_health

	call music

	mov nn,OAM
	mov [nn+0],33
	mov [nn+1],55
	mov [nn+2],0
	mov [nn+3],OAM_ENABLE

		mov a,5
		mov [frankdir],a

level_2_stuff:
		mov		a, [screennumber] 
		cmp		a, 11
		jz		screen11setup	

level_2:
		jmp	screen_11_stuff		
	
	
	
;-----------------------------------------------------------------------------
; screen 11 setup
;-----------------------------------------------------------------------------
screen11setup: 
	movb	b, 95
    movw	HL, TILEMAP+95
bglinear11:
    movb	[HL], b   ### write the counter variable to the map
    dec		HL        ### decrease map address
    jdbnz       bglinear11
	
    movw	sp,REG_BASE
    movw	nn,REG_BASE		
	
		mov		x1, screen1
		movw	[REG_BASE+REG_LCD_TILEBGMEM], x1


	
	mov nn,OAM
	mov [nn+4],nextsnowtimer
	mov [nn+5],1
	mov [nn+6],2
	mov [nn+7],OAM_ENABLE	
	
		mov x1, TILEMAP+23
		mov a, 2	
		mov [x1], a
		
		mov x1, TILEMAP+35
		mov a, 2	
		mov [x1], a
		
		call show_health

		mov a,0
		mov [buttonpress],a	
		mov [bites],a

		mov nn,REG_BASE		
		
		jmp level_1		
	
	
;----------------
; screen 11 stuff
;----------------
screen_11_stuff:
		call snow_falling
		
		jmp level_1
	
;--------------
; snow_screens
;--------------	
snow_falling:
		mov		a, [snowtimer]
		inc 	a
		mov		[snowtimer], a
		
		mov		a, [nextsnowtimer]
		inc 	a
		mov		[nextsnowtimer], a		
		
		mov		a, [snowtimer] 
		cmp		a, 0
		jz		fall_that_snow_now

		ret

snow_timer_secs:
		mov		a, [snowtimersecs]
		inc 	a
		mov		[snowtimersecs], a
		
		mov		a, [snowtimersecs] 
		cmp		a, 2
		jz		fall_that_snow_now
		
		ret

fall_that_snow_now:
		mov a,0
		mov [snowtimersecs],a	


		mov		a, [OAM+5]
		inc 	a
		mov		[OAM+5], a
		
		mov		a, [OAM+5] 
		cmp		a, 80
		jz		new_snow

		ret

new_snow:
		mov a,1
		mov [OAM+5],a

		mov a, [nextsnowtimer]	
		mov [OAM+4], a	

		ret
	
;-----------------------------------------------------------------------------	
; health meter
;-----------------------------------------------------------------------------	
show_health:
		mov x1, TILEMAP+72
		mov a, [health10]	
		mov [x1], a

		mov x1, TILEMAP+84
		mov a, [health]
		mov [x1], a	

		ret

;-----------------------------------------------------------------------------
; add to health
;-----------------------------------------------------------------------------
add_score:	
	mov b, 0
	mov a, 1
	shl a
	shl a
	mov hl, sfx_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playsfx
	
		mov		a, [health] 
		cmp		a, 106
		jg		add_tens
	
		call show_health
	
		ret
		
add_tens:
		mov		a, [health]
		sub		a, 10
		mov		[health], a

		mov		a, [health10]
		inc 	a
		mov		[health10], a
		
		mov		a, [health10] 
		cmp		a, 106
		jg		health_is_99		
		
		call show_health	
		
		ret
		
health_is_99:
		mov a,106
		mov [health],a	
		mov [health10],a

		call show_health
	
		ret
;-----------------------------------------------------------------------------	
; music
;-----------------------------------------------------------------------------	
music:
	mov b, 0
	mov a, [bgm_select]
	shl a
	shl a
	mov hl, bgm_list+2
	add hl, ba
	mov b, [hl]
	dec hl
	dec hl
	mov hl, [hl]
	call pmmusic_playbgm
	
	ret

;-----------------------------------------------------------------------------
; Read Keypad Return A, 0 = Released, 1 = Pressed
;-----------------------------------------------------------------------------
read_keys:
	mov a, [n+KEY_PAD]
	push b
	mov b, [n+KEY_PAD]
	xor a, b
	mov a, b
	pop b
	jnz read_keys
	not a
	ret		
	
;-----------------------------------------------------------------------------
; suspend or not
;-----------------------------------------------------------------------------
do_i_suspend:
	test	[nn+BUTTONS], BUTTON_POWER
	jnz		_dont_suspend2
	int		IntSuspend
_dont_suspend2:
	ret

;-----------------------------------------------------------------------------
; Files it uses
;-----------------------------------------------------------------------------
	.align 16
	
sfx_list:
	.dd sound_fx0
	.dd sound_fx1
	
sfx_list_last:	.db 2	
bgm_list_last:	.db 3	

bgm_list:
	.dd music_test2
	.dd music_level_intro	
	.dd level_1_music

	PMMUSIC_ALIGN

sound_fx0:
	PMMUSIC_ROW N_C_5, $80, 3, 1
	PMMUSIC_ROW N_B_4, $80, 3, 1
	PMMUSIC_ROW N_A_4, $80, 3, 1
	PMMUSIC_END

sound_fx1:
	PMMUSIC_ROW N_C_5, $80, 3, 1
	PMMUSIC_ROW N_E_5, $80, 3, 1
	PMMUSIC_ROW N_G_5, $80, 3, 1
	PMMUSIC_ROW N_C_6, $80, 3, 1
	PMMUSIC_END

	.include "music_title2.asm"		
	.include "music_title4.asm"
	.include "level_1_music.asm"	

	pm_align_tiles
titlescreenpic:
	.incbin franktitle.bin	
title1:
	.incbin franktitle3a.bin	
title2:
	.incbin franktitle3b.bin		
	
level1intro:
	.incbin franklevel1intro.bin
level2intro:
	.incbin franklevel2intro.bin
screen1:
	.incbin frankscreen1a.bin	
screen3:
	.incbin frankscreen3.bin	
screen4:
	.incbin ftffscreen4c.bin	
screen5:
	.incbin frankscreen5.bin		
screen6:
	.incbin frankscreen6.bin	
screen7:
	.incbin frankscreen7.bin
screen8:
	.incbin frankscreen8.bin
screen9:
	.incbin frankscreen9.bin
screen10:
	.incbin frankscreen10.bin

	pm_align_spr
player:
	.incbin franksprites6.bin
player2:
	.incbin frankspriteslevel2.bin